/// <reference types="react" />
import { type CompProps } from './Composition.js';
import type { TCompMetadata, TComposition, TRenderAsset, TSequence } from './CompositionManager.js';
import type { CompositionManagerContext } from './CompositionManagerContext.js';
import * as CSSUtils from './default-css.js';
import type { RemotionEnvironment } from './get-remotion-environment.js';
import type { SerializedJSONWithCustomFields } from './input-props-serialization.js';
import type { SetTimelineContextValue, TimelineContextValue } from './timeline-position-state.js';
import * as TimelinePosition from './timeline-position-state.js';
import { truthy } from './truthy.js';
import type { MediaVolumeContextValue, SetMediaVolumeContextValue } from './volume-position-state.js';
import type { WatchRemotionStaticFilesPayload } from './watch-static-file.js';
import { useRemotionContexts } from './wrap-remotion-context.js';
export declare const Internals: {
    readonly useUnsafeVideoConfig: () => import("./video-config.js").VideoConfig | null;
    readonly Timeline: typeof TimelinePosition;
    readonly CompositionManager: import("react").Context<CompositionManagerContext>;
    readonly SequenceManager: import("react").Context<import("./SequenceManager.js").SequenceManagerContext>;
    readonly SequenceVisibilityToggleContext: import("react").Context<import("./SequenceManager.js").SequenceVisibilityToggleState>;
    readonly RemotionRoot: import("react").FC<{
        children: import("react").ReactNode;
        numberOfAudioTags: number;
    }>;
    readonly useVideo: () => (import("./video-config.js").VideoConfig & {
        component: import("react").LazyExoticComponent<import("react").ComponentType<Record<string, unknown>>>;
    }) | null;
    readonly getRoot: () => import("react").FC<{}> | null;
    readonly useMediaVolumeState: () => readonly [number, (u: number) => void];
    readonly useMediaMutedState: () => readonly [boolean, (u: import("react").SetStateAction<boolean>) => void];
    readonly useLazyComponent: <Props>(compProps: CompProps<Props>) => import("react").ExoticComponent<(import("react").PropsWithoutRef<Props> & import("react").RefAttributes<import("react").Component<Props, any, any>>) | import("react").PropsWithRef<Props>> & {
        readonly _result: import("react").ComponentType<Props>;
    };
    readonly truthy: typeof truthy;
    readonly SequenceContext: import("react").Context<import("./SequenceContext.js").SequenceContextType | null>;
    readonly useRemotionContexts: typeof useRemotionContexts;
    readonly RemotionContextProvider: (props: import("./wrap-remotion-context.js").RemotionContextProviderProps) => import("react/jsx-runtime.js").JSX.Element;
    readonly CSSUtils: typeof CSSUtils;
    readonly setupEnvVariables: () => void;
    readonly MediaVolumeContext: import("react").Context<MediaVolumeContextValue>;
    readonly SetMediaVolumeContext: import("react").Context<SetMediaVolumeContextValue>;
    readonly getRemotionEnvironment: () => RemotionEnvironment;
    readonly SharedAudioContext: import("react").Context<{
        registerAudio: (aud: import("./index.js").RemotionAudioProps, audioId: string) => {
            id: number;
            props: import("./index.js").RemotionAudioProps;
            el: import("react").RefObject<HTMLAudioElement>;
            audioId: string;
        };
        unregisterAudio: (id: number) => void;
        updateAudio: (options: {
            id: number;
            aud: import("./index.js").RemotionAudioProps;
            audioId: string;
        }) => void;
        playAllAudios: () => void;
        numberOfAudioTags: number;
    } | null>;
    readonly SharedAudioContextProvider: import("react").FC<{
        numberOfAudioTags: number;
        children: import("react").ReactNode;
        component: import("react").LazyExoticComponent<import("react").ComponentType<Record<string, unknown>>> | null;
    }>;
    readonly invalidCompositionErrorMessage: string;
    readonly isCompositionIdValid: (id: string) => RegExpMatchArray | null;
    readonly getPreviewDomElement: () => HTMLElement | null;
    readonly compositionsRef: import("react").RefObject<{
        getCompositions: () => import("./CompositionManager.js").TCompMetadataWithCalcFunction<import("zod").AnyZodObject, Record<string, unknown>>[];
    }>;
    readonly portalNode: () => HTMLElement;
    readonly waitForRoot: (fn: (comp: import("react").FC<{}>) => void) => () => void;
    readonly CanUseRemotionHooksProvider: import("react").FC<{
        children: import("react").ReactNode;
    }>;
    readonly CanUseRemotionHooks: import("react").Context<boolean>;
    readonly PrefetchProvider: import("react").FC<{
        children: import("react").ReactNode;
    }>;
    readonly DurationsContextProvider: import("react").FC<{
        children: import("react").ReactNode;
    }>;
    readonly IsPlayerContextProvider: import("react").FC<{
        children?: import("react").ReactNode;
    }>;
    readonly useIsPlayer: () => boolean;
    readonly EditorPropsProvider: import("react").FC<{
        children: import("react").ReactNode;
    }>;
    readonly EditorPropsContext: import("react").Context<import("./EditorProps.js").EditorPropsContextType>;
    readonly usePreload: (src: string) => string;
    readonly NonceContext: import("react").Context<import("./nonce.js").TNonceContext>;
    readonly resolveVideoConfig: ({ composition, editorProps: editorPropsOrUndefined, signal, inputProps, }: {
        composition: import("./CompositionManager.js").TCompMetadataWithCalcFunction<import("zod").AnyZodObject, Record<string, unknown>>;
        editorProps: object;
        signal: AbortSignal;
        inputProps: Record<string, unknown>;
    }) => import("./video-config.js").VideoConfig | Promise<import("./video-config.js").VideoConfig>;
    readonly useResolvedVideoConfig: (preferredCompositionId: string | null) => ({
        type: "loading";
    } | {
        type: "success";
        result: import("./video-config.js").VideoConfig;
    } | {
        type: "error";
        error: Error;
    }) | null;
    readonly resolveCompositionsRef: import("react").RefObject<{
        setCurrentRenderModalComposition: (compositionId: string | null) => void;
        reloadCurrentlySelectedComposition: () => void;
    }>;
    readonly ResolveCompositionConfig: import("react").FC<import("react").PropsWithChildren<{
        children: import("react").ReactNode;
    }>>;
    readonly REMOTION_STUDIO_CONTAINER_ELEMENT: "__remotion-studio-container";
    readonly RenderAssetManager: import("react").Context<import("./RenderAssetManager.js").RenderAssetManagerContext>;
    readonly persistCurrentFrame: (time: {
        [x: string]: number;
    }) => void;
    readonly useTimelineSetFrame: () => (u: import("react").SetStateAction<Record<string, number>>) => void;
    readonly FILE_TOKEN: "remotion-file:";
    readonly DATE_TOKEN: "remotion-date:";
    readonly NativeLayersProvider: import("react").FC<{
        children?: import("react").ReactNode;
    }>;
    readonly ClipComposition: import("react").FC<{
        children?: import("react").ReactNode;
    }>;
    readonly isIosSafari: () => boolean;
    readonly WATCH_REMOTION_STATIC_FILES: "remotion_staticFilesChanged";
    readonly addSequenceStackTraces: (component: unknown) => void;
    readonly useMediaStartsAt: () => number;
    readonly enableSequenceStackTraces: () => void;
    readonly colorNames: {
        [key: string]: number;
    };
};
export type { TComposition, TimelinePosition as Timeline, TCompMetadata, TSequence, TRenderAsset as TAsset, TimelineContextValue, SetTimelineContextValue, CompProps, CompositionManagerContext, MediaVolumeContextValue, SetMediaVolumeContextValue, RemotionEnvironment, SerializedJSONWithCustomFields, WatchRemotionStaticFilesPayload, };
